==> openigtlink_1.10.5.orig.tar.gz: openigtlink-1.10.5/Testing/igtlutil/igtl_test_data_point.h <==
/*=========================================================================

  Program:   OpenIGTLLink Library -- Dummy point data
  Module:    $RCSfile: $
  Language:  C
  Date:      $Date: $
  Version:   $Revision: $

  Copyright (c) Insight Software Consortium. All rights reserved.

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notices for more information.

=========================================================================*/

#ifndef __IGTL_TEST_DATA_POINT_H
#define __IGTL_TEST_DATA_POINT_H

char test_point_message[] = {
  /*------- OpenIGTLink message header --------*/
  0x00, 0x01,                                     /* Version number */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* POINT */
  0x44, 0x65, 0x76, 0x69, 0x63, 0x65, 0x4e, 0x61,
  0x6d, 0x65, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Device name */
  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd2, /* Time stamp */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x98, /* Body size */
  0xa5, 0x5c, 0xc6, 0x2d, 0x99, 0xc1, 0x82, 0x10, /* CRC */

  /*---------- POINT message body ------------*/
  /* Image meta data 0 */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x61, 0x6e, 0x64, 0x6d, 0x61, 0x72, 0x6b,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Group name (Landmark etc.) */

  0xff, 0x00, 0x00, 0xff,                         /* RGBA */

  0x41, 0x20, 0x00, 0x00, 0x41, 0x70, 0x00, 0x00,
  0x41, 0xa0, 0x00, 0x00,                         /* Position */

  0x40, 0xa0, 0x00, 0x00,                         /* Radius */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 1 */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x61, 0x6e, 0x64, 0x6d, 0x61, 0x72, 0x6b,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Group name (Landmark etc.) */

  0x00, 0xff, 0x00, 0xff,                         /* RGBA */

  0x41, 0xc8, 0x00, 0x00, 0x41, 0xf0, 0x00, 0x00,
  0x42, 0x0c, 0x00, 0x00,                         /* Position */

  0x40, 0x40, 0x00, 0x00,                         /* Radius */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 2 */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x61, 0x6e, 0x64, 0x6d, 0x61, 0x72, 0x6b,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Group name (Landmark etc.) */

  0x00, 0x00, 0xff, 0xff,                         /* RGBA */

  0x42, 0x20, 0x00, 0x00, 0x42, 0x34, 0x00, 0x00,
  0x42, 0x48, 0x00, 0x00,                         /* Position */

  0x3f, 0x80, 0x00, 0x00,                         /* Radius */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

};

#endif /* IGTL_TEST_DATA_POINT_H */

==> openigtlink_3.0.0.orig.tar.gz: openigtlink-3.0.0/Testing/igtlutil/igtl_test_data_point.h <==
/*=========================================================================

  Program:   OpenIGTLLink Library -- Dummy point data
  Module:    $RCSfile: $
  Language:  C
  Date:      $Date: $
  Version:   $Revision: $

  Copyright (c) Insight Software Consortium. All rights reserved.

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notices for more information.

=========================================================================*/

#ifndef __IGTL_TEST_DATA_POINT_H
#define __IGTL_TEST_DATA_POINT_H

unsigned char test_point_message[] = {
  /*------- OpenIGTLink message header --------*/
  0x00, 0x01,                                     /* Version number */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* POINT */
  0x44, 0x65, 0x76, 0x69, 0x63, 0x65, 0x4e, 0x61,
  0x6d, 0x65, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Device name */
  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd4, /* Time stamp */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x98, /* Body size */
  0xa5, 0x5c, 0xc6, 0x2d, 0x99, 0xc1, 0x82, 0x10, /* CRC */

  /*---------- POINT message body ------------*/
  /* Image meta data 0 */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x61, 0x6e, 0x64, 0x6d, 0x61, 0x72, 0x6b,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Group name (Landmark etc.) */

  0xff, 0x00, 0x00, 0xff,                         /* RGBA */

  0x41, 0x20, 0x00, 0x00, 0x41, 0x70, 0x00, 0x00,
  0x41, 0xa0, 0x00, 0x00,                         /* Position */

  0x40, 0xa0, 0x00, 0x00,                         /* Radius */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 1 */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x31, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x61, 0x6e, 0x64, 0x6d, 0x61, 0x72, 0x6b,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Group name (Landmark etc.) */

  0x00, 0xff, 0x00, 0xff,                         /* RGBA */

  0x41, 0xc8, 0x00, 0x00, 0x41, 0xf0, 0x00, 0x00,
  0x42, 0x0c, 0x00, 0x00,                         /* Position */

  0x40, 0x40, 0x00, 0x00,                         /* Radius */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

  /* Image meta data 2 */
  0x50, 0x4f, 0x49, 0x4e, 0x54, 0x5f, 0x44, 0x45,
  0x53, 0x43, 0x52, 0x49, 0x50, 0x54, 0x49, 0x4f,
  0x4e, 0x5f, 0x32, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Image description */

  0x4c, 0x61, 0x6e, 0x64, 0x6d, 0x61, 0x72, 0x6b,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, /* Group name (Landmark etc.) */

  0x00, 0x00, 0xff, 0xff,                         /* RGBA */

  0x42, 0x20, 0x00, 0x00, 0x42, 0x34, 0x00, 0x00,
  0x42, 0x48, 0x00, 0x00,                         /* Position */

  0x3f, 0x80, 0x00, 0x00,                         /* Radius */

  0x49, 0x4d, 0x41, 0x47, 0x45, 0x5f, 0x30, 0x00,
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Owner image */

};

#endif /* IGTL_TEST_DATA_POINT_H */
